@@ -1,15 +1,17 @@
 import pytest
-from thinc.api import Config, ConfigValidationError
-import spacy
-from spacy.lang.en import English
-from spacy.lang.de import German
-from spacy.language import Language, DEFAULT_CONFIG, DEFAULT_CONFIG_PRETRAIN_PATH
-from spacy.util import registry, load_model_from_config, load_config
-from spacy.ml.models import build_Tok2Vec_model, build_tb_parser_model
-from spacy.ml.models import MultiHashEmbed, MaxoutWindowEncoder
-from spacy.schemas import ConfigSchema, ConfigSchemaPretrain
 from catalogue import RegistryError
+from thinc.api import Config, ConfigValidationError
 
+import spacy
+from spacy.lang.de import German
+from spacy.lang.en import English
+from spacy.language import DEFAULT_CONFIG, DEFAULT_CONFIG_PRETRAIN_PATH
+from spacy.language import Language
+from spacy.ml.models import MaxoutWindowEncoder, MultiHashEmbed
+from spacy.ml.models import build_tb_parser_model, build_Tok2Vec_model
+from spacy.schemas import ConfigSchema, ConfigSchemaPretrain
+from spacy.util import load_config, load_config_from_str
+from spacy.util import load_model_from_config, registry
 
 from ..util import make_tempdir
 
@@ -182,6 +184,25 @@ def my_parser():
     return parser
 
 
+@pytest.mark.issue(8190)
+def test_issue8190():
+    """Test that config overrides are not lost after load is complete."""
+    source_cfg = {
+        "nlp": {
+            "lang": "en",
+        },
+        "custom": {"key": "value"},
+    }
+    source_nlp = English.from_config(source_cfg)
+    with make_tempdir() as dir_path:
+        # We need to create a loadable source pipeline
+        source_path = dir_path / "test_model"
+        source_nlp.to_disk(source_path)
+        nlp = spacy.load(source_path, config={"custom": {"key": "updated_value"}})
+
+        assert nlp.config["custom"]["key"] == "updated_value"
+
+
 def test_create_nlp_from_config():
     config = Config().from_str(nlp_config_string)
     with pytest.raises(ConfigValidationError):
@@ -233,7 +254,7 @@ def test_create_nlp_from_config_multiple_instances():
 
 
 def test_serialize_nlp():
-    """ Create a custom nlp pipeline from config and ensure it serializes it correctly """
+    """Create a custom nlp pipeline from config and ensure it serializes it correctly"""
     nlp_config = Config().from_str(nlp_config_string)
     nlp = load_model_from_config(nlp_config, auto_fill=True)
     nlp.get_pipe("tagger").add_label("A")
@@ -253,7 +274,7 @@ def test_serialize_nlp():
 
 
 def test_serialize_custom_nlp():
-    """ Create a custom nlp pipeline and ensure it serializes it correctly"""
+    """Create a custom nlp pipeline and ensure it serializes it correctly"""
     nlp = English()
     parser_cfg = dict()
     parser_cfg["model"] = {"@architectures": "my_test_parser"}
@@ -274,7 +295,7 @@ def test_serialize_custom_nlp():
     "parser_config_string", [parser_config_string_upper, parser_config_string_no_upper]
 )
 def test_serialize_parser(parser_config_string):
-    """ Create a non-default parser config to check nlp serializes it correctly """
+    """Create a non-default parser config to check nlp serializes it correctly"""
     nlp = English()
     model_config = Config().from_str(parser_config_string)
     parser = nlp.add_pipe("parser", config=model_config)
@@ -465,3 +486,32 @@ def test_config_only_resolve_relevant_blocks():
         nlp.initialize()
     nlp.config["initialize"]["lookups"] = None
     nlp.initialize()
+
+
+def test_hyphen_in_config():
+    hyphen_config_str = """
+    [nlp]
+    lang = "en"
+    pipeline = ["my_punctual_component"]
+
+    [components]
+
+    [components.my_punctual_component]
+    factory = "my_punctual_component"
+    punctuation = ["?","-"]
+    """
+
+    @spacy.Language.factory("my_punctual_component")
+    class MyPunctualComponent(object):
+        name = "my_punctual_component"
+
+        def __init__(
+            self,
+            nlp,
+            name,
+            punctuation,
+        ):
+            self.punctuation = punctuation
+
+    nlp = English.from_config(load_config_from_str(hyphen_config_str))
+    assert nlp.get_pipe("my_punctual_component").punctuation == ["?", "-"]
